#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_NOTAND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_NOTAND_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/bitwise_notand.hpp>

#endif
